@@ -38,7 +38,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAccessGroup", params)
+            headers = request.headers
+            body = self.call("CreateAccessGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAccessGroupResponse()
@@ -68,7 +69,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAccessRules", params)
+            headers = request.headers
+            body = self.call("CreateAccessRules", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateAccessRulesResponse()
@@ -98,7 +100,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateFileSystem", params)
+            headers = request.headers
+            body = self.call("CreateFileSystem", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateFileSystemResponse()
@@ -128,7 +131,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateLifeCycleRules", params)
+            headers = request.headers
+            body = self.call("CreateLifeCycleRules", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateLifeCycleRulesResponse()
@@ -158,7 +162,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateMountPoint", params)
+            headers = request.headers
+            body = self.call("CreateMountPoint", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateMountPointResponse()
@@ -188,7 +193,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateRestoreTasks", params)
+            headers = request.headers
+            body = self.call("CreateRestoreTasks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateRestoreTasksResponse()
@@ -218,7 +224,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAccessGroup", params)
+            headers = request.headers
+            body = self.call("DeleteAccessGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteAccessGroupResponse()
@@ -248,7 +255,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAccessRules", params)
+            headers = request.headers
+            body = self.call("DeleteAccessRules", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteAccessRulesResponse()
@@ -278,7 +286,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteFileSystem", params)
+            headers = request.headers
+            body = self.call("DeleteFileSystem", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteFileSystemResponse()
@@ -308,7 +317,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteLifeCycleRules", params)
+            headers = request.headers
+            body = self.call("DeleteLifeCycleRules", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteLifeCycleRulesResponse()
@@ -338,7 +348,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteMountPoint", params)
+            headers = request.headers
+            body = self.call("DeleteMountPoint", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteMountPointResponse()
@@ -368,7 +379,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAccessGroups", params)
+            headers = request.headers
+            body = self.call("DescribeAccessGroups", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAccessGroupsResponse()
@@ -398,7 +410,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAccessRules", params)
+            headers = request.headers
+            body = self.call("DescribeAccessRules", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeAccessRulesResponse()
@@ -428,7 +441,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeFileSystem", params)
+            headers = request.headers
+            body = self.call("DescribeFileSystem", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeFileSystemResponse()
@@ -458,7 +472,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeFileSystems", params)
+            headers = request.headers
+            body = self.call("DescribeFileSystems", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeFileSystemsResponse()
@@ -488,7 +503,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeLifeCycleRules", params)
+            headers = request.headers
+            body = self.call("DescribeLifeCycleRules", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeLifeCycleRulesResponse()
@@ -518,7 +534,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMountPoint", params)
+            headers = request.headers
+            body = self.call("DescribeMountPoint", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeMountPointResponse()
@@ -548,7 +565,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMountPoints", params)
+            headers = request.headers
+            body = self.call("DescribeMountPoints", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeMountPointsResponse()
@@ -578,7 +596,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeResourceTags", params)
+            headers = request.headers
+            body = self.call("DescribeResourceTags", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeResourceTagsResponse()
@@ -608,7 +627,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRestoreTasks", params)
+            headers = request.headers
+            body = self.call("DescribeRestoreTasks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeRestoreTasksResponse()
@@ -638,7 +658,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAccessGroup", params)
+            headers = request.headers
+            body = self.call("ModifyAccessGroup", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAccessGroupResponse()
@@ -668,7 +689,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAccessRules", params)
+            headers = request.headers
+            body = self.call("ModifyAccessRules", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyAccessRulesResponse()
@@ -698,7 +720,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyFileSystem", params)
+            headers = request.headers
+            body = self.call("ModifyFileSystem", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyFileSystemResponse()
@@ -728,7 +751,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyLifeCycleRules", params)
+            headers = request.headers
+            body = self.call("ModifyLifeCycleRules", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyLifeCycleRulesResponse()
@@ -758,7 +782,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyMountPoint", params)
+            headers = request.headers
+            body = self.call("ModifyMountPoint", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyMountPointResponse()
@@ -788,7 +813,8 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyResourceTags", params)
+            headers = request.headers
+            body = self.call("ModifyResourceTags", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ModifyResourceTagsResponse()
